Calibration tool: pyFAI-recalib
===============================

pyFAI-recalib is now obsolete. All feature provided by it are now available as part of pyFAI-calib.

.. command-output:: pyFAI-recalib --help
    :nostderr: